Welcome to Pydipole's documentation!
=======================================

`Pydipole <https://github.com/AtomPolarTable/dipole-polarizability>`_ is a Python package to maintain
Table of atomic dipole polarizability for neutural atoms in the Periodic Table.

This version contains contributions from
Peter Schwerdtfeger (1)
Jeffrey K. Nagle (2)
YingXing Cheng (3),

- (1) Centre for Theoretical Chemistry and Physics, Massey University, Auckland, New Zealand.
- (2) Department of Chemistry, Bowdoin College, Brunswick, ME, USA.
- (3) Numerical Mathematics for High-Performance Computing (NMH), University of Stuttgart, Stuttgart, Germany.

The ``pydipole`` source code is hosted on GitHub and is released under the GNU General Public License v3.0.
Please report any issues you encounter while using ``pydipole`` library on
`GitHub Issues <https://github.com/AtomPolarTable/dipole-polarizability/issues/new>`_.
For further information and inquiries please contact us at yxcheng2buaa@gmail.com.

Tables
======

- The 2023 Table is available `here <https://github.com/AtomPolarTable/dipole-polarizability/blob/main/tables/2023/main.pdf>`_.


Citations
=========

Please use the following citations in any publication using ``pydipole`` library:

[1] Schwerdtfeger, P.; Nagle, J. K.
**2018 Table of static dipole polarizabilities of the neutral elements in the periodic table.**
`Molecular Physics 2019, 117 (9-12), 1200–1225 <https://doi.org/10.1080/00268976.2018.1535143>`_


Modules
=======

.. csv-table::
    :file: ./table_modules.csv
    :widths: 50, 70
    :delim: ;
    :header-rows: 1
    :align: center


.. toctree::
    :maxdepth: 2
    :caption: User Documentation

    ./installation.rst

.. toctree::
    :maxdepth: 1
    :caption: Quick Start

    ./notebooks/table.ipynb


.. toctree::
   :maxdepth: 2
   :caption: API Documentation

   pyapi/modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
